import document from 'arg.js/src/document';
import cuit from 'arg.js/src/cuit';
import phone from 'arg.js/src/phone';

import {
    size, inRange, parseInt, isDate, isEqual, isNaN
} from 'lodash';

// eslint-disable-next-line max-len
const emailRegex = /^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
const numberRegex = /[0-9]+/;
const dateRegex = /^\d{4}\-(0[1-9]|1[012])\-(0[1-9]|[12][0-9]|3[01])$/;


export default class ValidatorService {
    static validateText(input, max = 50, min = 2) {
        return inRange(size(input), min, max + 1);
    }

    static validateNumber(input) {
        if (input === '.') {
            return true;
        }
        return numberRegex.test(input);
    }

    static validateDate(input) {
        return dateRegex.test(input)
    }

    static validateEmail(email) {
        return emailRegex.test(email);
    }

    static validateDocument(input) {
        return input && !isNaN(parseInt(input)) && document.isValidDni(input);
    }

    static validateCuil(cuil) {
        return cuit.isValid(cuil);
    }

    static validateCompare(input, compareInput, max = 50, min = 2) {
        return inRange(size(input), min, max) && isEqual(input, compareInput);
    }

    static validatePhone(input) {
        try{
            if(size(input) >= 8){
                const phoneClean = phone.clean(input);
                if(phoneClean !== ''){
                    return {
                        error: {status: 'valid', message: 'Formato valido'},
                        value: phoneClean
                    }
                }
            }
            return {
                error: {status: 'invalid', message: 'Formato invalido'},
                value: input
            }
        } catch (error) {
            return {
                error: {status: 'invalid', message: 'Formato invalido'},
                value: input
            }
        }
    }
}
